@@ -4,7 +4,7 @@
 ###################
 #    This file implement some functions to manage requests/reports on
 #    WebScripts
-#    Copyright (C) 2021  Maurice Lambert
+#    Copyright (C) 2021, 2022, 2023  Maurice Lambert
 
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 ###################
 
-"""This tool run scripts and display the result in a Web Interface.
+"""#    This tool runs CLI scripts and displays output in a Web Interface.
 
 This file implement some functions to manage requests/reports on WebScripts.
 """
@@ -31,7 +31,7 @@ __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
 __maintainer_email__ = "mauricelambert434@gmail.com"
 __description__ = """
-This tool run scripts and display the result in a Web Interface.
+This tool runs CLI scripts and displays output in a Web Interface.
 
 This file implement some functions to manage requests/reports on WebScripts
 """
@@ -39,7 +39,7 @@ __license__ = "GPL-3.0 License"
 __url__ = "https://github.com/mauricelambert/WebScripts"
 
 copyright = """
-WebScripts  Copyright (C) 2021  Maurice Lambert
+WebScripts  Copyright (C) 2021, 2022, 2023  Maurice Lambert
 This program comes with ABSOLUTELY NO WARRANTY.
 This is free software, and you are welcome to redistribute it
 under certain conditions.
@@ -85,7 +85,6 @@ DIRECTORY = path.join(
 
 
 def anti_XSS(named_tuple: namedtuple) -> namedtuple:
-
     """
     This function returns a namedtuple without HTML special characters.
     """
@@ -97,7 +96,6 @@ def anti_XSS(named_tuple: namedtuple) -> namedtuple:
 
 
 def get_requests() -> Iterator[Request]:
-
     """This function build Request from database."""
 
     yield from map(
@@ -110,7 +108,6 @@ def get_requests() -> Iterator[Request]:
 
 
 def get_request(id_: str) -> Request:
-
     """This function return a specific request."""
 
     for request in get_requests():
@@ -121,7 +118,6 @@ def get_request(id_: str) -> Request:
 
 
 def delete_request(id_: str) -> Request:
-
     """
     This function rewrite the request database without the specified request.
     """
