@@ -3,7 +3,7 @@
 
 ###################
 #    This file uploads a file on a WebScripts Server
-#    Copyright (C) 2021  Maurice Lambert
+#    Copyright (C) 2021, 2022, 2023  Maurice Lambert
 
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 #    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 ###################
 
-"""This tool run scripts and display the result in a Web Interface.
+"""#    This tool runs CLI scripts and displays output in a Web Interface.
 
 This file uploads a file on a WebScripts Server."""
 
@@ -29,14 +29,14 @@ __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
 __maintainer_email__ = "mauricelambert434@gmail.com"
 __description__ = """
-This tool run scripts and display the result in a Web Interface.
+This tool runs CLI scripts and displays output in a Web Interface.
 
 This file uploads a file on a WebScripts Server"""
 __license__ = "GPL-3.0 License"
 __url__ = "https://github.com/mauricelambert/WebScripts"
 
 copyright = """
-WebScripts  Copyright (C) 2021  Maurice Lambert
+WebScripts  Copyright (C) 2021, 2022, 2023  Maurice Lambert
 This program comes with ABSOLUTELY NO WARRANTY.
 This is free software, and you are welcome to redistribute it
 under certain conditions.
@@ -52,7 +52,6 @@ import sys
 
 
 def parse_args() -> Namespace:
-
     """This function parse command line arguments."""
 
     owner = get_user()
@@ -113,7 +112,6 @@ def parse_args() -> Namespace:
 
 
 def main() -> None:
-
     """This function uploads a file on a WebScripts Server."""
 
     arguments = parse_args()
